@@ -1,5 +1,5 @@
 """knex: Python library for creating chainable data transformers."""
-__version__ = "0.2.14"
+__version__ = "0.5.0"
 
 __all__ = [
     "Start",
@@ -18,6 +18,9 @@ __all__ = [
     "FirstElement",
     "LastElement",
     "TextFSMParse",
+    "MacAddress",
+    "IndexOf",
+    "Join",
 ]
 
 from .parsers import (
@@ -37,4 +40,7 @@ from .parsers import (
     FirstElement,
     LastElement,
     TextFSMParse,
+    MacAddress,
+    IndexOf,
+    Join,
 )
